@@ -2,15 +2,15 @@ pub mod accelerometer;
 pub mod command;
 pub mod image;
 pub mod multi;
-mod runecoral_inference;
 pub mod raw;
+mod runecoral_inference;
 pub mod sound;
 
 use hotg_rune_runtime::ParameterError;
 
 pub use self::{
     accelerometer::Accelerometer, sound::Sound, image::Image, raw::Raw,
-    multi::new_multiplexer, command::Run,
+    multi::new_capability_switcher, command::Run,
 };
 
 use hotg_rune_core::Value;
